@@ -232,14 +232,14 @@ class GenericControllerClass:
             if(len(sql_data["sql_for_insert_cluster_execute"]["member_sql"]) > 0):
                 flag_data["flag_update_report"] = True
 
-                print("Insert cluster member ...")
+                # print("Insert cluster member ...")
                 sql_member_insert_cluster = sql_data["sql_for_insert_cluster_execute"]["member_sql"]
                 if(len(sql_data["sql_for_insert_cluster_execute"]["member_values"]) > 0):
                     sql_data["sql_for_insert_cluster_execute"]["member_values"] = [None if i is 'null' else i for i in sql_data["sql_for_insert_cluster_execute"]["member_values"]]
                     connect_db_output.queryExecute(sql_member_insert_cluster, sql_data["sql_for_insert_cluster_execute"]["member_values"], "")
                 else:
                     connect_db_output.queryExecute(sql_member_insert_cluster, None, "")
-                print("Insert cluster member successfully")
+                # print("Insert cluster member successfully")
 
                 # UtilsController.genLog(sql_member_insert_cluster, "info")
                 sql_data["sql_for_insert_cluster_execute"]["member_sql"] = ""
@@ -247,14 +247,14 @@ class GenericControllerClass:
 
             if(len(sql_data["sql_for_insert_cluster_execute"]["member_details_sql"]) > 0):
                 flag_data["flag_update_report"] = True
-                print("Insert cluster member detail ...")
+                # print("Insert cluster member detail ...")
                 sql_member_detail_insert_cluster = sql_data["sql_for_insert_cluster_execute"]["member_details_sql"]
                 if(len(sql_data["sql_for_insert_cluster_execute"]["member_details_values"]) > 0):
                     sql_data["sql_for_insert_cluster_execute"]["member_details_values"] = [None if i is 'null' else i for i in sql_data["sql_for_insert_cluster_execute"]["member_details_values"]]
                     connect_db_output.queryExecute(sql_member_detail_insert_cluster, sql_data["sql_for_insert_cluster_execute"]["member_details_values"], "")
                 else:
                     connect_db_output.queryExecute(sql_member_detail_insert_cluster, None, "")
-                print("Insert cluster member detail successfully")
+                # print("Insert cluster member detail successfully")
 
                 # UtilsController.genLog(sql_member_detail_insert_cluster, "info")
                 sql_data["sql_for_insert_cluster_execute"]["member_details_sql"] = ""
@@ -262,7 +262,7 @@ class GenericControllerClass:
 
             if(len(sql_data["sql_for_insert_cluster_execute"]["summary_sql"]) > 0):
                 flag_data["flag_update_report"] = True
-                print("Insert cluster summary ...")
+                # print("Insert cluster summary ...")
                 sql_summary_insert_cluster = sql_data["sql_for_insert_cluster_execute"]["summary_sql"]
 
                 if(len(sql_data["sql_for_insert_cluster_execute"]["summary_values"]) > 0):
@@ -270,7 +270,7 @@ class GenericControllerClass:
                     connect_db_output.queryExecute(sql_summary_insert_cluster , sql_data["sql_for_insert_cluster_execute"]["summary_values"], "")
                 else:
                     connect_db_output.queryExecute(sql_summary_insert_cluster , None, "")
-                print("Insert cluster summary successfully")
+                # print("Insert cluster summary successfully")
 
                 # UtilsController.genLog(sql_summary_insert_cluster, "info")
                 sql_data["sql_for_insert_cluster_execute"]["summary_sql"] = ""
@@ -278,7 +278,7 @@ class GenericControllerClass:
                 
             if(len(sql_data["sql_for_insert_cluster_execute"]["summary_details_sql"]) > 0):
                 flag_data["flag_update_report"] = True
-                print("Insert cluster summary detail ...")
+                # print("Insert cluster summary detail ...")
                 sql_summary_detail_insert_cluster = sql_data["sql_for_insert_cluster_execute"]["summary_details_sql"]
 
                 if(len(sql_data["sql_for_insert_cluster_execute"]["summary_details_values"]) > 0):
@@ -286,7 +286,7 @@ class GenericControllerClass:
                     connect_db_output.queryExecute(sql_summary_detail_insert_cluster, sql_data["sql_for_insert_cluster_execute"]["summary_details_values"], "")
                 else:
                     connect_db_output.queryExecute(sql_summary_detail_insert_cluster, sql_data["sql_for_insert_cluster_execute"]["summary_details_values"], "")
-                print("Insert cluster summary detail successfully")
+                # print("Insert cluster summary detail successfully")
                 # UtilsController.genLog(sql_summary_detail_insert_cluster, "info")
                 sql_data["sql_for_insert_cluster_execute"]["summary_details_sql"] = ""
                 sql_data["sql_for_insert_cluster_execute"]["summary_details_values"] = []
@@ -303,15 +303,15 @@ class GenericControllerClass:
     def executeInsertNewCluster(self, connect_db_output, flag_data, sql_data, generic):
         try:
             if(len(sql_data["sql_for_insert_execute"]["report_sql"]) > 0):
-                print("Insert new cluster report ...")
+                # print("Insert new cluster report ...")
                 sql_report_insert = sql_data["sql_for_insert_execute"]["report_sql"]
                 if(len(sql_data["sql_for_insert_execute"]["report_values"]) > 0):
                     my_cursor = connect_db_output.queryExecute(sql_report_insert, sql_data["sql_for_insert_execute"]["report_values"], "fetchone")
                 else:
                     my_cursor = connect_db_output.queryExecute(sql_report_insert, None, "fetchone")
-                print("Insert new cluster report successfully")
+                # print("Insert new cluster report successfully")
                 sql_data = self.replaceSqlReport(sql_data, my_cursor, connect_db_output.flag_return_data[0])
-                print("Insert new cluster member ...")
+                # print("Insert new cluster member ...")
 
                 sql_member_insert = sql_data["sql_for_insert_execute"]["member_sql"]
 
@@ -320,36 +320,36 @@ class GenericControllerClass:
                     connect_db_output.queryExecute(sql_member_insert, sql_data["sql_for_insert_execute"]["member_values"], "")
                 else:
                     connect_db_output.queryExecute(sql_member_insert, None, "")
-                print("Insert new cluster member successfully")
+                # print("Insert new cluster member successfully")
                 if(len(sql_data["sql_for_insert_execute"]["member_details_sql"]) > 0):
-                    print("Insert new cluster member detail ...")
+                    # print("Insert new cluster member detail ...")
                     sql_member_detail_insert = sql_data["sql_for_insert_execute"]["member_details_sql"]
 
                     if(len(sql_data["sql_for_insert_execute"]["member_details_values"]) > 0):
                         connect_db_output.queryExecute(sql_member_detail_insert, sql_data["sql_for_insert_execute"]["member_details_values"], "")
                     else:
                         connect_db_output.queryExecute(sql_member_detail_insert, None, "")
-                    print("Insert new cluster member detail successfully")
+                    # print("Insert new cluster member detail successfully")
                     # UtilsController.genLog(sql_member_detail_insert, "info")       
 
                 if(len(sql_data["sql_for_insert_execute"]["summary_sql"]) > 0):
-                    print("Insert new cluster summary ...")
+                    # print("Insert new cluster summary ...")
                     sql_summary_insert = sql_data["sql_for_insert_execute"]["summary_sql"]
                     if(len(sql_data["sql_for_insert_execute"]["summary_values"]) > 0):
                         connect_db_output.queryExecute(sql_summary_insert , sql_data["sql_for_insert_execute"]["summary_values"], "")
                     else:
                         connect_db_output.queryExecute(sql_summary_insert , None, "")
-                    print("Insert new cluster summary successfully")
+                    # print("Insert new cluster summary successfully")
                 # UtilsController.genLog(sql_summary_insert, "info")
 
                 if(len(sql_data["sql_for_insert_execute"]["summary_details_sql"]) > 0):
-                    print("Insert new cluster summary detail ...")
+                    # print("Insert new cluster summary detail ...")
                     sql_summary_detail_insert = sql_data["sql_for_insert_execute"]["summary_details_sql"]
                     if(len(sql_data["sql_for_insert_execute"]["summary_details_values"]) > 0):
                         connect_db_output.queryExecute(sql_summary_detail_insert, sql_data["sql_for_insert_execute"]["summary_details_values"], "")
                     else:
                         connect_db_output.queryExecute(sql_summary_detail_insert, None, "")
-                    print("Insert new cluster summary detail successfully")
+                    # print("Insert new cluster summary detail successfully")
                     # UtilsController.genLog(sql_summary_detail_insert, "info")
 
                 sql_data["sql_for_insert_execute"]["report_sql"] = ""
@@ -379,42 +379,42 @@ class GenericControllerClass:
         try:     
             if(len(sql_data["sql_for_update_execute"]["member_sql"]) > 0):
                 flag_data["flag_update_report"] = True
-                print("Update member ...")
+                # print("Update member ...")
                 sql_member_update = sql_data["sql_for_update_execute"]["member_sql"]
                 if(len(sql_data["sql_for_update_execute"]["member_sql_values"]) > 0):
                     sql_data["sql_for_update_execute"]["member_sql_values"] = [None if i is 'null' else i for i in sql_data["sql_for_update_execute"]["member_sql_values"]]
                     my_cursor = connect_db_output.queryExecute(sql_member_update, sql_data["sql_for_update_execute"]["member_sql_values"], "")
                 else:
                     my_cursor = connect_db_output.queryExecute(sql_member_update, None, "")
-                print("Update member successfully ...")
+                # print("Update member successfully ...")
                 # UtilsController.genLog(sql_member_update, "info")
                 sql_data["sql_for_update_execute"]["member_sql"] = ""
                 sql_data["sql_for_update_execute"]["member_sql_values"] = []
 
             if(len(sql_data["sql_for_update_execute"]["member_details_sql"]) > 0):
                 flag_data["flag_update_report"] = True
-                print("Update member detail ...")
+                # print("Update member detail ...")
                 sql_member_detail_update = sql_data["sql_for_update_execute"]["member_details_sql"]
                 if(len(sql_data["sql_for_update_execute"]["member_details_sql_values"]) > 0):
                     sql_data["sql_for_update_execute"]["member_details_sql_values"] = [None if i is 'null' else i for i in sql_data["sql_for_update_execute"]["member_details_sql_values"]]
                     my_cursor = connect_db_output.queryExecute(sql_member_detail_update, sql_data["sql_for_update_execute"]["member_details_sql_values"], "")
                 else:
                     my_cursor = connect_db_output.queryExecute(sql_member_detail_update, None, "")
-                print("Update member detail successfully ...")
+                # print("Update member detail successfully ...")
                 # UtilsController.genLog(sql_member_detail_update, "info")
                 sql_data["sql_for_update_execute"]["member_details_sql"] = ""
                 sql_data["sql_for_update_execute"]["member_details_sql_values"] = []
 
             if(len(sql_data["sql_for_update_execute"]["summary_sql"]) > 0):
                 flag_data["flag_update_report"] = True
-                print("Update summary...")
+                # print("Update summary...")
                 sql_summary_update = sql_data["sql_for_update_execute"]["summary_sql"]
                 if(len(sql_data["sql_for_update_execute"]["summary_sql_values"]) > 0):
                     sql_data["sql_for_update_execute"]["summary_sql_values"] = [None if i is 'null' else i for i in sql_data["sql_for_update_execute"]["summary_sql_values"]]
                     my_cursor = connect_db_output.queryExecute(sql_summary_update, sql_data["sql_for_update_execute"]["summary_sql_values"], "")
                 else:
                     my_cursor = connect_db_output.queryExecute(sql_summary_update, None, "")
-                print("Update summary successfully...")
+                # print("Update summary successfully...")
                 if(my_cursor.rowcount == 0 and len(sql_data["sql_for_update_execute"]["summary_false_sql"]) and len(sql_data["sql_for_update_execute"]["summary_false_sql_values"])):
                     # all active false
                     my_cursor = connect_db_output.queryExecute(sql_data["sql_for_update_execute"]["summary_false_sql"], sql_data["sql_for_update_execute"]["summary_false_sql_values"], "")
@@ -425,7 +425,7 @@ class GenericControllerClass:
                 sql_data["sql_for_update_execute"]["summary_false_sql_values"] = []
             
             if(len(sql_data["sql_for_update_execute"]["summary_details_sql"]) > 0):
-                print("Update summary detail ...")
+                # print("Update summary detail ...")
                 flag_data["flag_update_report"] = True
                 sql_summary_detail_update = sql_data["sql_for_update_execute"]["summary_details_sql"]
                 if(len(sql_data["sql_for_update_execute"]["summary_details_sql_values"]) > 0):
@@ -433,7 +433,7 @@ class GenericControllerClass:
                     my_cursor = connect_db_output.queryExecute(sql_summary_detail_update, sql_data["sql_for_update_execute"]["summary_details_sql_values"], "fetchall")
                 else:
                     my_cursor = connect_db_output.queryExecute(sql_summary_detail_update, None, "fetchall")
-                print("Update summary detail successfully...")
+                # print("Update summary detail successfully...")
                 if(my_cursor.rowcount == 0 and len(sql_data["sql_for_update_execute"]["summary_false_details_sql"]) and len(sql_data["sql_for_update_execute"]["summary_false_details_sql_values"])):
                     # all active false
                     my_cursor = connect_db_output.queryExecute(sql_data["sql_for_update_execute"]["summary_false_details_sql"], sql_data["sql_for_update_execute"]["summary_false_details_sql_values"], "")
@@ -449,7 +449,7 @@ class GenericControllerClass:
                 sql_data["sql_for_update_execute"]["summary_false_details_sql_values"] = []
 
             if(flag_data["flag_update_report"]):
-                print("Update report ...")
+                # print("Update report ...")
                 sql_data["sql_for_update_execute"] = self.controller_app["report"].genSqlReportUpdateByRepresentativeProcess(connect_db_output, sql_data["sql_for_update_execute"], flag_data["flag_representative_list_df"], generic)
                 sql_report_update = sql_data["sql_for_update_execute"]["report_sql"]
                 # UtilsController.genLog(sql_report_update, "info")
@@ -459,15 +459,15 @@ class GenericControllerClass:
                     my_cursor = connect_db_output.queryExecute(sql_report_update, None, "")
                 sql_data["sql_for_update_execute"]["report_sql"] = ""
                 sql_data["sql_for_update_execute"]["report_sql_values"] = []
-                print("Update report successfully ...")
+                # print("Update report successfully ...")
 
-                print("Check Representative Date ...")
+                # print("Check Representative Date ...")
                 sql_update_date = self.genSqlUpdateRepresentativeDate(connect_db_output, flag_data["flag_representative_id_list"], generic)
                 if(sql_update_date != "" and sql_update_date != False):
                     my_cursor = connect_db_output.queryExecute(sql_update_date, None, "")
                 flag_data["flag_representative_id_list"] = []
                 flag_data["flag_representative_list_df"] = []
-                print("Check Representative Date successfully ...")
+                # print("Check Representative Date successfully ...")
 
         except Exception as error:
             exc_type, exc_obj, exc_tb = sys.exc_info()
@@ -500,7 +500,7 @@ class GenericControllerClass:
             if(self.executeSQLUpdateCluster(connect_db_output, flag_data, sql_data, generic) == False):
                 return False
 
-            print("Process successfully !!!")
+            # print("Process successfully !!!")
             return True
         except Exception as error:
             exc_type, exc_obj, exc_tb = sys.exc_info()
